/*
 *     file: I18N.java
 *  package: org.eclipse.swt.sleak.core
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.core;

import java.util.ResourceBundle;

/**
 * Contains constants for Strings used for internationalization.
 * <p>
 * Note that the person translator need only submit a new I18N.properties file in this
 * package for the appropriate locale according to the
 * <code>java.util.ResourceBundle</code> documentation. The main usage of this file for
 * the translator is in seeing the context of the string constants. Each constant is
 * commented according to how it is used.
 * </p>
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see java.util.ResourceBundle
 */
final class I18N {

    /** Error for when the device is not tracking data. */
    final static String ERR_NOT_TRACKING;

    /** Error for when the an object cant be categorized. */
    final static String ERR_CANT_CATEGORIZE;

    /** Error for when there is a monitoring conflict. */
    final static String ERR_ALREADY_MONITORING;

    /** Error for when snapshots have the wrong creation times in creating a delta. */
    final static String ERR_CREATION_TIMES;

    static {
        final String bundleName = I18N.class.getName();
        final ResourceBundle bundle = ResourceBundle.getBundle(bundleName);
        ERR_NOT_TRACKING = bundle.getString("ERR_NOT_TRACKING"); //$NON-NLS-1$
        ERR_CANT_CATEGORIZE = bundle.getString("ERR_CANT_CATEGORIZE"); //$NON-NLS-1$
        ERR_CREATION_TIMES = bundle.getString("ERR_CREATION_TIMES"); //$NON-NLS-1$
        ERR_ALREADY_MONITORING = bundle.getString("ERR_ALREADY_MONITORING"); //$NON-NLS-1$
    }
}

/* ########## End of File ########## */