/*
 *     file: SLeakPlugin.java
 *  package: org.eclipse.swt.sleak.plugin
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin;

import java.util.ArrayList;
import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.regex.tools.ui.RegexPatternSetFieldEditor;
import org.eclipse.swt.sleak.plugin.preference.SLeakPreferenceConstants;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

/**
 * The main plugin class to be used in the desktop.
 */
public class SLeakPlugin extends AbstractUIPlugin implements BundleActivator {

    /** The ID of thep plugin. */
    public final static String ID = SLeakPlugin.class.getName();

    /** The shared instance. */
    private static SLeakPlugin plugin;

    /**
     * Fetch an Image from a path inside the plugin.
     * <p>
     * <b>Note that the caller is responsible for disposing of returned images. </b>
     * </p>
     * 
     * @param path The path and filename of the icon relative to the plugin home.
     * @return The constructed image.
     */
    public final static ImageDescriptor getPluginImage(final String path) {
        return AbstractUIPlugin.imageDescriptorFromPlugin(SLeakPlugin.ID, path);
    }

    /**
     * Builds a new <code>SLeakPlugin</code> instance.
     */
    public SLeakPlugin() {
        super();
        SLeakPlugin.plugin = this;
    }

    /**
     * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * @return The plugin shared instance.
     */
    public static SLeakPlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the workspace instance.
     */
    public static IWorkspace getWorkspace() {
        return ResourcesPlugin.getWorkspace();
    }

    /**
     * @see org.eclipse.ui.plugin.AbstractUIPlugin#initializeDefaultPreferences(org.eclipse.jface.preference.IPreferenceStore)
     */
    protected void initializeDefaultPreferences(final IPreferenceStore store) {
        final String defaultFilters = RegexPatternSetFieldEditor.encodePatterns(new ArrayList());
        store.setDefault(SLeakPreferenceConstants.FILTER_PATTERNS, defaultFilters); //$NON-NLS-1$
    }
}

/* ########## End of File ########## */