/*
 *     file: I18N.java
 *  package: org.eclipse.swt.sleak.plugin.views
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin.views;

import java.util.ResourceBundle;

/**
 * Contains constants for Strings used for internationalization.
 * <p>
 * Note that the person translator need only submit a new I18N.properties file in this
 * package for the appropriate locale according to the
 * <code>java.util.ResourceBundle</code> documentation. The main usage of this file for
 * the translator is in seeing the context of the string constants. Each constant is
 * commented according to how it is used.
 * </p>
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see java.util.ResourceBundle
 */
final class I18N {

    // ---------------- Error Messages ----------------

    /** Error message used for when an element is given and its type is not recognized. */
    final static String ERR_UNEXPECTED_ELEMENT;

    // ---------------- General Strings ----------------

    /** String for the "snapshot" button. */
    final static String SNAPSHOT_BUTTON_LABEL;

    /** String for the "delta" button. */
    final static String DELTA_BUTTON_LABEL;

    /** Root element item for the tree of caches.. */
    final static String ROOT_ELEMENT;

    /** Tooltip text for the preview panel. */
    final static String TOOLTIP_PREVIEW;

    /** Tooltip text for the stack trace panel. */
    final static String TOOLTIP_TRACE;

    /** Tooltip text for the preview panel. */
    final static String TOOLTIP_CACHE_TREE;

    /** Label for the preview panel tab. */
    final static String LBL_PREVIEW;

    /** Label for the stack trace panel tab. */
    final static String LBL_TRACE;

    static {
        final String bundleName = I18N.class.getName();
        final ResourceBundle bundle = ResourceBundle.getBundle(bundleName);

        ERR_UNEXPECTED_ELEMENT = bundle.getString("ERR_UNEXPECTED_ELEMENT"); //$NON-NLS-1$

        SNAPSHOT_BUTTON_LABEL = bundle.getString("SNAPSHOT_BUTTON_LABEL"); //$NON-NLS-1$
        DELTA_BUTTON_LABEL = bundle.getString("DELTA_BUTTON_LABEL"); //$NON-NLS-1$
        ROOT_ELEMENT = bundle.getString("ROOT_ELEMENT"); //$NON-NLS-1$
        TOOLTIP_PREVIEW = bundle.getString("TOOLTIP_PREVIEW"); //$NON-NLS-1$
        TOOLTIP_TRACE = bundle.getString("TOOLTIP_TRACE"); //$NON-NLS-1$
        TOOLTIP_CACHE_TREE = bundle.getString("TOOLTIP_CACHE_TREE"); //$NON-NLS-1$
        LBL_PREVIEW = bundle.getString("LBL_PREVIEW"); //$NON-NLS-1$
        LBL_TRACE = bundle.getString("LBL_TRACE"); //$NON-NLS-1$
    }
}

/* ########## End of File ########## */