/*
 *     file: DeviceDataCache.java
 *  package: org.eclipse.swt.sleak.core
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.core;

import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.SortedSet;
import java.util.TreeSet;

/**
 * The base of all device data cache types.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 */
abstract class DeviceDataCache implements Comparable, IDeviceDataCache {

    /** The time that the cache was created. */
    private final Date creationTime = Calendar.getInstance().getTime();

    /** The data cahced in this instance. */
    private final Map cacheData = new HashMap();

    /**
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(final Object obj) {
        return this.getCreationTime().compareTo(((IDeviceDataCache)obj).getCreationTime());
    }

    /**
     * Creates a new <code>DeviceDataCache</code>.
     */
    DeviceDataCache() {
        // -- Create the cacheData map structure.
        for (final Iterator iter = ObjectCategory.getAllCategories().iterator(); iter.hasNext();) {
            final ObjectCategory category = (ObjectCategory)iter.next();
            this.cacheData.put(category, new TreeSet());
        }
    }

    /**
     * @see org.eclipse.swt.sleak.core.IDeviceDataCache#getCategory(org.eclipse.swt.sleak.core.ObjectCategory)
     */
    protected SortedSet getCategoryInternal(final ObjectCategory category) {
        return (SortedSet)this.cacheData.get(category);
    }

    /**
     * @see org.eclipse.swt.sleak.core.IDeviceDataCache#getCategory(org.eclipse.swt.sleak.core.ObjectCategory)
     */
    public SortedSet getCategory(final ObjectCategory category) {
        return Collections.unmodifiableSortedSet(getCategoryInternal(category));
    }

    /**
     * @see org.eclipse.swt.sleak.core.IDeviceDataCache#getCreationTime()
     */
    public Date getCreationTime() {
        return this.creationTime;
    }
}

/* ########## End of File ########## */