/*
 *     file: IObjectDeviceData.java
 *  package: org.eclipse.swt.sleak.core
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.core;

/**
 * Contains device data for a single object. The objects are categorized by major type
 * such as Icons, Cursors and Fonts. This class is essentially a decorator for the object
 * class that provides more information on the object such as its category.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 */
public interface IObjectDeviceData {

    /**
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(final Object obj);

    /**
     * Getter for category: The category of object.
     * 
     * @return Returns the category.
     */
    public ObjectCategory getCategory();

    /**
     * Getter for object: A reference to the object that this device data refers to.
     * 
     * @return Returns the object.
     */
    public Object getObject();

    /**
     * Getter for stackTrace: The stack trace recorded at the time the object was created.
     * 
     * @return Returns the stackTrace.
     */
    public StackTraceElement[] getStackTrace();

}
/* ########## End of File ########## */