/*
 *     file: SnapshotDeviceDataCache.java
 *  package: org.eclipse.swt.sleak.core
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.core;

import java.util.SortedSet;
import org.eclipse.swt.graphics.DeviceData;
import org.eclipse.swt.widgets.Display;

/**
 * Default implementation of <code>ISnapshotDeviceDataCache</code>.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.swt.sleak.core.ISnapshotDeviceDataCache
 */
class SnapshotDeviceDataCache extends DeviceDataCache implements ISnapshotDeviceDataCache {

    /** The display pertaining to this snapshot. */
    final Display display;

    /**
     * Creates a new <code>DeviceDataCache</code> with the given parameters.
     * 
     * @param display The display to use to find data.
     */
    SnapshotDeviceDataCache(final Display display) {
        super();
        this.display = display;

        // -- Fetch the data from the display.
        final DeviceData deviceData = display.getDeviceData();

        // -- If the device isnt tracking, there is nothing we can do.
        if (!deviceData.tracking) {
            throw new IllegalStateException(I18N.ERR_NOT_TRACKING);
        }

        // -- Iterate through the objects and pack their info in the cache.
        // Sorts them into the category maps under the parsed map. The hashCode()
        // of the SWT target resource is used as the key to the catagory specific
        // maps.
        for (int idx = 0; idx < deviceData.objects.length; idx++) {
            final Object target = deviceData.objects[idx];
            final StackTraceElement[] trace = deviceData.errors[idx].getStackTrace();
            final IObjectDeviceData data = new ObjectDeviceData(target, trace);
            final SortedSet targetSet = getCategoryInternal(data.getCategory());
            targetSet.add(data);
        }

    }

    /**
     * @see org.eclipse.swt.sleak.core.ISnapshotDeviceDataCache#getDisplay()
     */
    public Display getDisplay() {
        return this.display;
    }
}

/* ########## End of File ########## */