/*
 *     file: I18N.java
 *  package: org.eclipse.swt.sleak.plugin.actions
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin.actions;

import java.util.ResourceBundle;

/**
 * Contains constants for Strings used for internationalization.
 * <p>
 * Note that the person translator need only submit a new I18N.properties file in this
 * package for the appropriate locale according to the
 * <code>java.util.ResourceBundle</code> documentation. The main usage of this file for
 * the translator is in seeing the context of the string constants. Each constant is
 * commented according to how it is used.
 * </p>
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see java.util.ResourceBundle
 */
final class I18N {

    // ---------------- General Strings ----------------

    /** Title for when the display is not tracking. */
    final static String TITLE_NOT_TRACKING;

    /** Message for when the display is not tracking. */
    final static String MSG_NOT_TRACKING;

    /** Name for the <code>Snapshot</code> action. */
    final static String ACTION_SNAPSHOT;

    /** Tooltip text for the <code>Snapshot</code> action. */
    final static String TOOLTIP_SNAPSHOT;

    /** Name for the <code>StartMonitor</code> action. */
    final static String ACTION_START_MONITOR;

    /** Tooltip text for <code>StartMonitor</code> action. */
    final static String TOOLTIP_START_MONITOR;

    /** Name for the <code>StopMonitor</code> action. */
    final static String ACTION_STOP_MONITOR;

    /** Tooltip text for <code>StopMonitor</code> action. */
    final static String TOOLTIP_STOP_MONITOR;

    /** Name for the <code>RemoveCache</code> action. */
    final static String ACTION_REMOVE_CACHE;

    /** Tooltip text for <code>RemoveCache</code> action. */
    final static String TOOLTIP_REMOVE_CACHE;

    /** Name for the <code>RemoveAllCaches</code> action. */
    final static String ACTION_REMOVE_ALL_CACHES;

    /** Tooltip text for <code>RemoveAllCaches</code> action. */
    final static String TOOLTIP_REMOVE_ALL_CACHES;

    static {
        final String bundleName = I18N.class.getName();
        final ResourceBundle bundle = ResourceBundle.getBundle(bundleName);

        TITLE_NOT_TRACKING = bundle.getString("TITLE_NOT_TRACKING"); //$NON-NLS-1$
        MSG_NOT_TRACKING = bundle.getString("MSG_NOT_TRACKING"); //$NON-NLS-1$
        ACTION_SNAPSHOT = bundle.getString("ACTION_SNAPSHOT"); //$NON-NLS-1$
        TOOLTIP_SNAPSHOT = bundle.getString("TOOLTIP_SNAPSHOT"); //$NON-NLS-1$
        ACTION_START_MONITOR = bundle.getString("ACTION_START_MONITOR"); //$NON-NLS-1$
        TOOLTIP_START_MONITOR = bundle.getString("TOOLTIP_START_MONITOR"); //$NON-NLS-1$
        ACTION_STOP_MONITOR = bundle.getString("ACTION_STOP_MONITOR"); //$NON-NLS-1$
        TOOLTIP_STOP_MONITOR = bundle.getString("TOOLTIP_STOP_MONITOR"); //$NON-NLS-1$
        ACTION_REMOVE_CACHE = bundle.getString("ACTION_REMOVE_CACHE"); //$NON-NLS-1$
        TOOLTIP_REMOVE_CACHE = bundle.getString("TOOLTIP_REMOVE_CACHE"); //$NON-NLS-1$
        ACTION_REMOVE_ALL_CACHES = bundle.getString("ACTION_REMOVE_ALL_CACHES"); //$NON-NLS-1$
        TOOLTIP_REMOVE_ALL_CACHES = bundle.getString("TOOLTIP_REMOVE_ALL_CACHES"); //$NON-NLS-1$
    }
}

/* ########## End of File ########## */